@@ -26,19 +26,20 @@ import { DatasourceItem } from './DatasourceItem';
 
 const JUPYTER_CELL_MIME = 'application/vnd.jupyter.cells';
 
-const datameshToken = (notebook: Notebook): string => {
-  const datameshTokenInjected =
-    notebook &&
-    notebook.widgets.find(cell => {
-      const line = cell.editor.getLine(0);
-      if (line && line.indexOf('DATAMESH_TOKEN=') >= 0) {
-        return true;
-      }
-    });
-  if (!datameshTokenInjected) {
-    return `DATAMESH_TOKEN='${window.datameshToken}';`;
-  }
-};
+// Not a good idea any more
+// const datameshToken = (notebook: Notebook): string => {
+//   const datameshTokenInjected =
+//     notebook &&
+//     notebook.widgets.find(cell => {
+//       const line = cell.editor.getLine(0);
+//       if (line && line.indexOf('DATAMESH_TOKEN=') >= 0) {
+//         return true;
+//       }
+//     });
+//   if (!datameshTokenInjected) {
+//     return `DATAMESH_TOKEN='${window.datameshToken}';`;
+//   }
+// };
 
 const datasourceCode = (
   datasource: IDatasource,
@@ -80,7 +81,7 @@ const datasourceCode = (
     datasourceStr =
       'from oceanum.datamesh import Connector' +
       '\n' +
-      '#Put your datamesh token in the Jupyterlab settings or as argument in the constructor below' +
+      '#Put your datamesh token in the Jupyterlab settings, or as argument in the constructor below' +
       '\n' +
       'datamesh=Connector()' +
       '\n' +
@@ -205,10 +206,10 @@ class DatameshWorkspaceDisplay extends React.Component<IDatameshWorkspaceProps>
       } else {
         notebookCellEditor.replaceSelection(datasourceStr);
       }
-      if (datameshTokenInject) {
-        NotebookActions.setCellCollapse(notebookContent.widgets[0], true);
-        //notebookContent.activeCellIndex = 0;
-      }
+      // if (datameshTokenInject) {
+      //   NotebookActions.setCellCollapse(notebookContent.widgets[0], true);
+      //   //notebookContent.activeCellIndex = 0;
+      // }
 
       // const cell = notebookWidget.model.contentFactory.createCodeCell({});
       // notebookWidget.model.cells.insert(notebookCellIndex + 1, cell);
